@@ -27,7 +27,9 @@ import (
 
 	minterv1 "github.com/openshift/cloud-credential-operator/pkg/apis/cloudcredential/v1"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/credentialsrequest/actuator"
+	"github.com/openshift/cloud-credential-operator/pkg/controller/credentialsrequest/constants"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/internalcontroller"
+	"github.com/openshift/cloud-credential-operator/pkg/controller/metrics"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/utils"
 
 	configv1 "github.com/openshift/api/config/v1"
@@ -50,6 +52,8 @@ import (
 )
 
 const (
+	controllerName = "credreq"
+
 	namespaceMissing = "NamespaceMissing"
 	namespaceExists  = "NamespaceExists"
 
@@ -258,8 +262,10 @@ type ReconcileCredentialsRequest struct {
 // +kubebuilder:rbac:groups=config.openshift.io,resources=infrastructures;dnses,verbs=get;list;watch
 // +kubebuilder:rbac:groups=config.openshift.io,resources=clusteroperators;clusteroperators/status,verbs=create;get;update;list;watch
 func (r *ReconcileCredentialsRequest) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+	start := time.Now()
+
 	logger := log.WithFields(log.Fields{
-		"controller": "credreq",
+		"controller": controllerName,
 		"cr":         fmt.Sprintf("%s/%s", request.NamespacedName.Namespace, request.NamespacedName.Name),
 	})
 
@@ -270,11 +276,22 @@ func (r *ReconcileCredentialsRequest) Reconcile(request reconcile.Request) (reco
 		if err != nil {
 			logger.WithError(err).Error("failed to sync operator status")
 		}
+		dur := time.Since(start)
+		metrics.MetricControllerReconcileTime.WithLabelValues(controllerName).Observe(dur.Seconds())
 	}()
 
+	operatorIsDisabled, err := utils.IsOperatorDisabled(r.Client, logger)
+	if err != nil {
+		logger.WithError(err).Error("error checking if operator is disabled")
+		return reconcile.Result{}, err
+	} else if operatorIsDisabled {
+		logger.Infof("operator disabled in %s ConfigMap", minterv1.CloudCredOperatorConfigMap)
+		return reconcile.Result{}, err
+	}
+
 	logger.Info("syncing credentials request")
 	cr := &minterv1.CredentialsRequest{}
-	err := r.Get(context.TODO(), request.NamespacedName, cr)
+	err = r.Get(context.TODO(), request.NamespacedName, cr)
 	if err != nil {
 		if errors.IsNotFound(err) {
 			logger.Debug("credentials request no longer exists")
@@ -396,12 +413,28 @@ func (r *ReconcileCredentialsRequest) Reconcile(request reconcile.Request) (reco
 	} else {
 		logger.Debug("found secret namespace")
 		setMissingTargetNamespaceCondition(cr, false)
+
+	}
+
+	// Check if the secret the credRequest wants created already exists
+	var crSecretExists bool
+	crSecret := &corev1.Secret{}
+	secretKey := types.NamespacedName{Name: cr.Spec.SecretRef.Name, Namespace: cr.Spec.SecretRef.Namespace}
+	if err := r.Get(context.TODO(), secretKey, crSecret); err != nil {
+		if errors.IsNotFound(err) {
+			crSecretExists = false
+		} else {
+			logger.WithError(err).Error("could not query whether secret already exists")
+			return reconcile.Result{}, err
+		}
+	} else {
+		crSecretExists = true
 	}
 
 	isStale := cr.Generation != cr.Status.LastSyncGeneration
 	hasRecentlySynced := cr.Status.LastSyncTimestamp != nil && cr.Status.LastSyncTimestamp.Add(time.Hour*1).After(time.Now())
 
-	if !isStale && hasRecentlySynced {
+	if !isStale && hasRecentlySynced && crSecretExists {
 		logger.Debug("lastsyncgeneration is current and lastsynctimestamp was less than an hour ago, so no need to sync")
 		return reconcile.Result{}, nil
 	}
@@ -568,7 +601,7 @@ func setIgnoredCondition(cr *minterv1.CredentialsRequest, clusterPlatform config
 
 	// Also clear any other conditions since we are ignoring this cred request,
 	// and we don't want to be in a degraded state b/c of cred requests that we're ignoring.
-	for _, cond := range failureConditionTypes {
+	for _, cond := range constants.FailureConditionTypes {
 		cr.Status.Conditions = utils.SetCredentialsRequestCondition(cr.Status.Conditions, cond,
 			corev1.ConditionFalse, reason, msg, updateCheck)
 	}
